********************************************************************************
********************************************************************************
****
**** Replication Code File 2 for:
****   Gerber, Huber, Biggers, and Hendry. "Self Interest, Beliefs, and Policy
****   Opinions: Understanding the Economic Source of Immigration Policy
****   Preferences." Political Research Quarterly.
****
****     - This file reads in the restricted raw dataset, recodes variables for
****       use in later analyses, and saves the recoded data as:
****
****         SelfInterestBeliefsPolicyOpinionsPRQ-Recodes.dta
****
********************************************************************************
********************************************************************************

clear
set more off

log using Logs/02_RecodeVariables-Run.txt, text replace

use Data/SelfInterestBeliefsPolicyOpinionsPRQ.dta, clear

*removing don't know responses from ideology and party id
tab ideo5
tab ideo5, nolab
recode ideo5 (6 = .)

tab pid7
tab pid7, nolab
recode pid7 (8 = .)

*generate measures of opposition to immigration
gen oppose_hs = YL45_28 if YL45_28_question == "highly skilled"
replace oppose_hs = YL45_29 if YL45_29_question == "highly skilled"
replace oppose_hs = (oppose_hs - 1) / 4

gen oppose_ls = YL45_28 if YL45_28_question == "low-skilled"
replace oppose_ls = YL45_29 if YL45_29_question == "low-skilled"
replace oppose_ls = (oppose_ls - 1) / 4

gen net_oppose_ls = oppose_ls - oppose_hs

*rescale variables to range between 0 and 1
foreach var of varlist YL45_49-YL45_52 YL45_57 {
  recode `var' (5 = 0) (4 = .25) (3 = .5) (2 = .75) (1 = 1) (* = .), /*
    */gen(rc_`var')
}

foreach var of varlist YL45_53 YL45_56a YL45_56e YL45_56h YL45_56j YL45_56n /*
  */YL45_56p YL45_61 {
      recode `var' (1 = 0) (2 = .25) (3 = .5) (4 = .75) (5 = 1) (* = .), /*
        */gen(rc_`var')
}

tab educ
recode educ (1 = 1) (2 = 2) (3 = 3) (4 = 3) (5 = 4) (6 = 4), gen(educ_hh)
replace educ_hh = educ_hh - 1
tab educ educ_hh
label define educ_hh 0 "No HS Degree" 1 "HS Degree" 2 "Some College" 3 /*
  */"BA or Higher"
label values educ_hh educ_hh

gen edu2 = 0
replace edu2 = 1 if educ > 2
tab educ edu2
label define edu2 0 "HS Degree or less" 1 "More than HS Degree"
label values edu2 edu2

tab gender
recode gender (1 = 0) (2 = 1), gen(female)
tab gender female
label define female 0 "Male" 1 "Female"
label values female female

gen age = 2013 - birthyr

tab race
gen black = 0
replace black = 1 if race == 2
tab race black
label define no0yes1 0 "No" 1 "Yes"
label values black no0yes1

gen white = 0
replace white = 1 if race == 1
tab race white
label values white no0yes1

tab hispanic
recode hispanic (1 = 1) (2 = 0), gen(latino)
tab hispanic latino
label values latino no0yes1

tab YL45_14a
recode YL45_14a (1 = 1) (2 = 0), gen(hs_dummy)
tab YL45_14a hs_dummy
label define hs_dummy 0 "Low-skilled" 1 "Highly skilled"
label values hs_dummy hs_dummy

gen oppose_pst_hs = YL45_71 if YL45_28_question == "highly skilled"
replace oppose_pst_hs = YL45_72 if YL45_29_question == "highly skilled"
replace oppose_pst_hs = (oppose_pst_hs - 1) / 4
label values oppose_pst_hs allow

gen oppose_pst_ls = YL45_71 if YL45_28_question == "low-skilled"
replace oppose_pst_ls = YL45_72 if YL45_29_question == "low-skilled"
replace oppose_pst_ls = (oppose_pst_ls - 1) / 4

*variable labels
label variable rc_YL45_49 "Increase household costs of goods and services"
label variable rc_YL45_50 "Increase household chance of job or wage loss"
label variable rc_YL45_51 "Increase household taxes"
label variable rc_YL45_52 "Reduce household access to government services"
label variable rc_YL45_53 "Overall hurt household finances"
label variable rc_YL45_56a "Unlikely to arrive speaking English"
label variable rc_YL45_56e "Unlikely to act lawfully"
label variable rc_YL45_56h "Unlikely to support U.S. political values"
label variable rc_YL45_56j "Unlikely to become part of American culture"
label variable rc_YL45_56n "Unlikely to raise children with US values"
label variable rc_YL45_56p "Unlikely to fit in"
label variable oppose_hs "Oppose admitting more highly skilled immigrants (0-1)"
label variable oppose_ls "Oppose admitting more low-skilled immigrants (0-1)"
label variable net_oppose_ls /*
  */"Opposition to low-skilled immigrants relative to highly skilled immigrants"
label variable female "Female (Yes = 1)"
label variable age "Age (in Years)"
label variable black "Black (Yes = 1)"
label variable white "White (Yes = 1)"
label variable latino "Hispanic (Yes = 1)"
label variable educ_hh "Education (0=No HS Degree to 3=BA or Higher)"
label variable ideo5 "Ideology (Very Liberal to Very Conservative, 5-pt.)"
label variable pid7 "Partisanship (Strong Democrat to Strong Republican, 7-pt.)"
label var hs_dummy "Self-assessed skill level (0 = Low, 1 = High)"
label var oppose_pst_hs /*
  */"Post: Oppose admitting more highly skilled immigrants (0-1)"
label var oppose_pst_ls /*
  */"Post: Oppose admitting more low-skilled immigrants (0-1)"

save Data/SelfInterestBeliefsPolicyOpinionsPRQ-Recodes.dta, replace

log close
